Crate hyte

Crate hyte 

hyte

hyte is hypothesis testing library intended to make conducting tests easier. In version v0.1.0, the following hypothesis tests are supported:

  • 1-sample Z-test
  • 1-sample T-test
  • 2-sample T-test
  • Pearson’s Chi-squared test of independence
  • Pearson’s Chi-squared test of goodness of fit

Source: GitHub

v0.1.0 by Abyan Majid (kinderheim511)

Modules

chisquare
Module responsible for all items needed to perform Pearson’s Chi-squared tests.
t
Module responsible for all items needed to perform T-tests.
utils
Module for data structures and additional utilities which the z, t, and chisquare modules depend on.
z
Module responsible for all items needed to perform Z-tests.

Functions

help
Prints a short manual for all utilities in hyte to the standard output.